@@ -1,8 +1,11 @@
 #
-# Copyright (C) 2011 - 2013 Satoru SATOH <ssato @ redhat.com>
+# Copyright (C) 2011 - 2014 Satoru SATOH <ssato @ redhat.com>
 # License: MIT
 #
+# Ref. python -c "import json; help(json)"
+#
 import anyconfig.backend.base as Base
+import anyconfig.compat as C
 import sys
 
 
@@ -20,14 +23,26 @@ def dict_to_container(json_obj_dict):
     return JsonConfigParser.container().create(json_obj_dict)
 
 
+_LOAD_OPTS = ["cls", "object_hook", "parse_float", "parse_int",
+              "parse_constant", "object_pairs_hook"]
+
+_DUMP_OPTS = ["skipkeys", "ensure_ascii", "check_circular", "allow_nan",
+              "cls", "indent", "separators", "default", "sort_keys"]
+
+# It seems that 'encoding' argument is not allowed in json.load[s] and
+# json.dump[s] in JSON module in python 3.x.
+if not C.IS_PYTHON_3:
+    _LOAD_OPTS.append("encoding")
+    _DUMP_OPTS.append("encoding")
+
+
 class JsonConfigParser(Base.ConfigParser):
     _type = "json"
     _extensions = ["json", "jsn", "js"]
     _supported = SUPPORTED
 
-    _load_opts = ["cls", "parse_float", "parse_int", "parse_constant"]
-    _dump_opts = ["cls", "skipkeys", "ensure_ascii", "check_circular",
-                  "allow_nan", "indent", "separators"]
+    _load_opts = _LOAD_OPTS
+    _dump_opts = _DUMP_OPTS
 
     @classmethod
     def loads(cls, config_content, **kwargs):
