@@ -2,6 +2,7 @@
 # Author: Satoru SATOH <ssato redhat.com>
 # License: MIT
 #
+# pylint: disable=W0611,F0401,C0111
 import sys
 
 
@@ -11,8 +12,9 @@ if IS_PYTHON_3:
     import configparser
     from io import StringIO
 
-    def iteritems(d):
-        return d.items()
+    def iteritems(dic):
+        """wrapper for dict.items()"""
+        return dic.items()
 else:
     import ConfigParser as configparser
     try:
@@ -20,7 +22,8 @@ else:
     except ImportError:
         from StringIO import StringIO
 
-    def iteritems(d):
-        return d.iteritems()
+    def iteritems(dic):
+        """wrapper for dict.iteritems()"""
+        return dic.iteritems()
 
 # vim:sw=4:ts=4:et:
