@@ -8,10 +8,20 @@ if `env | grep -q 'WITH_COVERAGE' 2>/dev/null`; then
     coverage_opts="--with-coverage --cover-tests --cover-inclusive"
 fi
 
+function _pylint () {
+    pylint --rcfile=$curdir/pylintrc --errors-only $@
+}
+
 which pep8 2>&1 > /dev/null && check_with_pep8=1 || check_with_pep8=0
+which pylint 2>&1 > /dev/null && check_with_pylint=1 || check_with_pylint=0
 
 if test $# -gt 0; then
-    test $check_with_pep8 = 1 && (for x in $@; do pep8 ${x%%:*}; done) || :
+    if test $check_with_pep8 = 1; then
+        for x in $@; do pep8 ${x%%:*}; done
+    fi
+    if test $check_with_pylint = 1; then
+        for x in $@; do _pylint ${x%%:*}; done
+    fi
     PYTHONPATH=$topdir nosetests -c $curdir/nose.cfg ${coverage_opts} $@
 else
     # Find out python package dir and run tests for .py files under it.
@@ -21,7 +31,8 @@ else
 
             for f in $(find ${pypkgdir} -name '*.py'); do
                 echo "[Info] Check $f..."
-                test $check_with_pep8 = 1 && pep8 $f || :
+                if test $check_with_pep8 = 1; then pep8 $f; fi
+                if test $check_with_pylint = 1; then _pylint $f; fi
                 PYTHONPATH=$topdir nosetests -c $curdir/nose.cfg \
                         ${coverage_opts} $f
             done
@@ -30,3 +41,5 @@ else
         fi
     done
 fi
+
+# vim:sw=4:ts=4:et:
